/*
 * @(#)src/classes/sov/com/sun/tools/example/trace/StreamRedirectThread.java, tool, asdev 1.6
 * ===========================================================================
 * IBM Confidential
 * OCO Source Materials
 *
 * IBM SDK, Java(tm) 2 Technology Edition, v5.0
 * (C) Copyright IBM Corp. 1998, 2005.
 *
 * The source code for this program is not published or otherwise divested of
 * its trade secrets, irrespective of what has been deposited with the U.S.
 * Copyright office.
 * ===========================================================================
 */

/*
 * ===========================================================================
 (C) Copyright Sun Microsystems Inc, 1992, 2004. All rights reserved.
 * ===========================================================================
 */



package com.sun.tools.example.trace;

import java.io.*;

/**
 * StreamRedirectThread is a thread which copies it's input to
 * it's output and terminates when it completes.
 *
 * @version     @(#) StreamRedirectThread.java 1.3 01/12/03 00:15:36
 * @author Robert Field
 */
class StreamRedirectThread extends Thread {

    private final Reader in;
    private final Writer out;

    private static final int BUFFER_SIZE = 2048;

    /**
     * Set up for copy.
     * @param name  Name of the thread
     * @param in    Stream to copy from
     * @param out   Stream to copy to
     */
    StreamRedirectThread(String name, InputStream in, OutputStream out) {
	super(name);
	this.in = new InputStreamReader(in);
	this.out = new OutputStreamWriter(out);
	setPriority(Thread.MAX_PRIORITY-1);
    }

    /**
     * Copy.
     */
    public void run() {
        try {
	    char[] cbuf = new char[BUFFER_SIZE];
	    int count;
	    while ((count = in.read(cbuf, 0, BUFFER_SIZE)) >= 0) {
		out.write(cbuf, 0, count);
	    }
            out.flush();
	} catch(IOException exc) {
	    System.err.println("Child I/O Transfer - " + exc);
	}
    }
}
